Am Freitag, dem 17.03.2023 um 14:45 +0000 schrieb Udicoudco:
> Please ignore the last patch, here is the correct one.

Isn't this the right patch? AFAIU we do not need to swap at all if
babel is used with Xe/LuaTeX, right?

-- 
Jürgen
diff --git a/src/Paragraph.cpp b/src/Paragraph.cpp
index 8650826e4f..c43421b376 100644
--- a/src/Paragraph.cpp
+++ b/src/Paragraph.cpp
@@ -2027,9 +2027,11 @@ char_type Paragraph::getUChar(BufferParams const & bparams,
 	char_type c = d->text_[pos];
 
 	// Return unchanged character in LTR languages
-	// or if we use poylglossia/bidi (XeTeX).
-	if (rp.useBidiPackage()
-	    || !getFontSettings(bparams, pos).isRightToLeft())
+	// or if we use poylglossia/bidi (XeTeX)
+	// or with babel and Xe/LuaTeX.
+	if (!getFontSettings(bparams, pos).isRightToLeft()
+	    || rp.useBidiPackage()
+	    || (rp.use_babel && rp.isFullUnicode()))
 		return c;
 
 	// Without polyglossia/bidi, we need to account for some special cases.
-- 
lyx-devel mailing list
[email protected]
http://lists.lyx.org/mailman/listinfo/lyx-devel

Reply via email to